@@ -9,16 +9,24 @@
 
 #include "k3bpatternparser.h"
 
-#include <KCddb/Cdinfo>
+#include <KCDDB/CDInfo>
 
 #include <KLocalizedString>
 
 #include <QDateTime>
 #include <QLocale>
 #include <QRegExp>
+#include <QRegularExpression>
 #include <QStack>
 #include <QDebug>
 
+static void replaceControlCharacters( QString& s )
+{
+    s.replace( '/', '_' );
+    s.replace( '*', '_' );
+    s.replace( '}', '*' );  // for conditional inclusion
+}
+
 QString K3b::PatternParser::parsePattern( const KCDDB::CDInfo& entry,
                                           int trackNumber,
                                           const QString& extension,
@@ -110,9 +118,7 @@ QString K3b::PatternParser::parsePattern( const KCDDB::CDInfo& entry,
                 switch( c ) {
                 case ARTIST:
                     s = entry.track( trackNumber-1 ).get( KCDDB::Artist ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );  // for conditional inclusion
+                    replaceControlCharacters( s );
                     dir.append( s.isEmpty()
                                 ? i18n("unknown") + QString(" %1").arg(trackNumber)
                                 : s );
@@ -123,9 +129,7 @@ QString K3b::PatternParser::parsePattern( const KCDDB::CDInfo& entry,
 #ifdef K3B_DEBUG
                     qDebug() << "DEBUG:" << __PRETTY_FUNCTION__ << s;
 #endif
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s.isEmpty()
                                 ? i18n("Track %1",trackNumber)
                                 : s );
@@ -138,41 +142,31 @@ QString K3b::PatternParser::parsePattern( const KCDDB::CDInfo& entry,
                     break;
                 case COMMENT:
                     s = entry.track( trackNumber-1 ).get( KCDDB::Comment ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s );
                     break;
                 case GENRE:
                     s = entry.get( KCDDB::Genre ).toString();
                     if ( s.isEmpty() )
                         s = entry.get( KCDDB::Category ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s );
                     break;
                 case ALBUMARTIST:
                     s = entry.get( KCDDB::Artist ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s.isEmpty()
                                 ? i18n("unknown") : s );
                     break;
                 case ALBUMTITLE:
                     s = entry.get( KCDDB::Title ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s.isEmpty()
                                 ? i18n("unknown") : s );
                     break;
                 case ALBUMCOMMENT:
                     s = entry.get( KCDDB::Comment ).toString();
-                    s.replace( '/', '_' );
-                    s.replace( '*', '_' );
-                    s.replace( '}', '*' );
+                    replaceControlCharacters( s );
                     dir.append( s ); // I think it makes more sense to allow empty comments
                     break;
                 case DATE:
@@ -315,8 +309,10 @@ QString K3b::PatternParser::parsePattern( const KCDDB::CDInfo& entry,
 
     dir.replace( '*', '}' );  // bring the brackets back, if there were any
 
-    if( replace )
-        dir.replace( QRegExp( "\\s" ), replaceString );
+    if( replace ) {
+        static const QRegularExpression rx( "\\s" );
+        dir.replace( rx, replaceString );
+    }
 
     if ( !dir.endsWith( '.' + extension ) )
         dir.append( '.' + extension );
